@@ -29,8 +29,7 @@ $basedir = "$basedir/qgvdial-$qver";
 # Delete any previous checkout directories
 system("rm -rf qgvdial-* qgvtp-* qgvdial_* qgvtp_*");
 
-$cmd = "svn export $repo $basedir";
-system($cmd);
+system("svn export $repo $basedir");
 system("cp $basedir/icons/64/qgvdial.png $basedir/src/qgvdial.png");
 
 # Append the version to the pro file
@@ -63,8 +62,7 @@ $cmd = "cd $basedir && dpkg-buildpackage -rfakeroot -sa -S -uc -us";
 # Execute the rest of the build command
 system($cmd);
 
-$cmd = "dput -f fremantle-upload qgvdial*.changes";
-system($cmd);
+system("dput -f fremantle-upload qgvdial*.changes");
 
 exit(0);
 
