@@ -24,6 +24,10 @@ Contact: yuvraaj@gmail.com
 
 #include "global.h"
 
+// For some reason the symbian MOC doesn't like it if I don't include QObject
+// even though it is present in QtCore which is included in global.h
+#include <QObject>
+
 class FuzzyTimerPrivate;
 class FuzzyTimer : public QObject
 {
